
class puppet::client {
    
    case $operatingsystem {
        OpenBSD: { $vardir = "/var/puppet" }
        default: { $vardir = "/var/lib/puppet" }
    }

    case $operatingsystem {
	centos,fedora: {
	    package { "ruby-shadow":
		ensure => installed,
	    }
	}
    }
        
    package { "puppet":
        name   => $operatingsystem ? {
            OpenBSD => "ruby-puppet",
            default => "puppet",
        },
        ensure => present,
    }
    
    file { "/etc/puppet/puppet.conf":
        ensure  => present,
        content => template("puppet/puppet.conf.erb"),
        mode    => 0600,
        owner   => root,
        group   => $operatingsystem ? {
            OpenBSD => wheel,
            default => root
        },
        require => Package["puppet"],
        notify  => Service["puppet"],
    }
    
    service { "puppet":
        ensure  => running,
        enable  => true,
        require => Package["puppet"],
    }
    
    case $operatingsystem {
        OpenBSD: {
            Service["puppet"] {
                binary  => "/usr/local/bin/puppetd",
                start   => "/usr/local/bin/puppetd",
                pattern => puppetd,
            }
        }
        default: {
            Service["puppet"] {
                hasrestart => true,
            }
        }
    }
    
}
